@@ -1,3 +1,4 @@
+import datetime
 import json
 import requests
 import ssl
@@ -5,6 +6,14 @@ import ssl
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.poolmanager import PoolManager
 
+DATE_FIELDS = [
+    'addAccountDate',
+    'closeDate',
+    'fiLastUpdated',
+    'lastUpdated',
+]
+
+
 class MintHTTPSAdapter(HTTPAdapter):
     def init_poolmanager(self, connections, maxsize, **kwargs):
         self.poolmanager = PoolManager(num_pools=connections, maxsize=maxsize, ssl_version=ssl.PROTOCOL_SSLv3, **kwargs)
@@ -15,7 +24,7 @@ def get_accounts(email, password):
     session.mount('https://', MintHTTPSAdapter())
 
     if session.get("https://wwws.mint.com/login.event?task=L").status_code != requests.codes.ok:
-        raise Exception("Failed to load Mint main page '{}'".format(Mint.START_URL))
+        raise Exception("Failed to load Mint login page")
     
     data = {"username": email, "password": password, "task": "L", "browser": "firefox", "browserVersion": "27", "os": "linux"}
     headers = {"accept": "application/json"}
@@ -57,8 +66,29 @@ def get_accounts(email, password):
         raise Exception("Could not parse account data: " + response)
     response = json.loads(response)
     accounts = response["response"][request_id]["response"]
+
+    # Return datetime objects for dates
+    for account in accounts:
+        for df in DATE_FIELDS:
+            if df in account:
+                # Convert from javascript timestamp to unix timestamp
+                # http://stackoverflow.com/a/9744811/5026
+                try:
+                    ts = account[df] / 1e3
+                except TypeError:
+                    # returned data is not a number, don't parse
+                    continue
+                account[df + 'InDate'] = datetime.datetime.fromtimestamp(ts)
+
     return accounts
 
+def print_accounts(accounts):
+    for account in accounts:
+        for k, v in account.items():
+            if isinstance(v, datetime.datetime):
+                account[k] = repr(v)
+    print(json.dumps(accounts, indent=2))
+
 def main():
     import getpass
     import sys
@@ -74,7 +104,7 @@ def main():
         password = getpass.getpass("Password: ")
 
     accounts = get_accounts(email, password)
-    print(json.dumps(accounts, indent=2))
-    
+    print_accounts(accounts)
+
 if __name__ == "__main__":
     main()
